@@ -2,7 +2,7 @@
 package twepl;
 use strict;
 use warnings;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 our $TIMEOUT = 2;
 local $SIG{ALRM} = sub{ die 'Force exiting, detected loop'; };
 my $STDBAK = *STDOUT;
@@ -18,8 +18,9 @@ my $src = $ref->{h} = '';
 exit unless open S,@ARGV ? shift @ARGV : exit;
 sysread S,$src,(-s S);
 close S;
-$src =~ s/^\#[^\r\n]+\s*//s;
-my($pos,$now,$tmp) = (1,0,'');
+my($pos,$now,$tmp) = (-1,0,'');
+$src =~ s/^\#[^\r\n]+//;
+$pos += $src  =~ s/^\r\n|^[\r\n]//gs;
 open TMP,'>>',\$tmp;
 *STDOUT = *TMP;
 alarm $TIMEOUT;
